@@ -10,11 +10,11 @@
 package org.gnu.gtk;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.ContainerEvent;
 import org.gnu.gtk.event.ContainerListener;
-import org.gnu.gtk.event.GtkEventType;
 
 import java.util.Vector;
 
@@ -199,8 +199,8 @@ public class Container extends Widget {
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
